#![allow(unused_doc_comments)]

#[macro_use] extern crate strum;
#[macro_use] extern crate log;
#[macro_use] extern crate smart_default;

pub mod cache;
pub mod cli;
pub mod fetch;
pub mod model;
pub mod proto;
pub mod proto_repository;
